--[[
AdiBags_Legion - Adds Legion filters to AdiBags.
Copyright 2016 Dia (mrdiablo@divine-pride.net)
All rights reserved.
--]]

local _, ns = ...

local addon = LibStub('AceAddon-3.0'):GetAddon('AdiBags')
local L = setmetatable({}, {__index = addon.L})
local MatchIDs

local function MatchIDs_Init(self)
  local Result = {}
  
  IDs = {
    137209, -- Armor Enhancement Token
	136412, -- Heavy Armor Set
	137207, -- Fortified Armor Set
	137208, -- Indestructible Armor Set
  }
  AddToSet(Result, IDs)
  
  return Result
end

function AddToSet(Set, List)
  for _, v in ipairs(List) do
    Set[v] = true
  end
end

do -- Localization
	L["Legion"] = "Legion"
	L["Artifact Power"] = "Artifact Power"
	L["Artifact Relic"] = "Artifact Relic"
	L["Champion's Equipment"] = "Champion's Equipment"
	L["Put Legion Stuff in their own sections."] = "Put Legion Stuff in their own sections."
end

local tooltip
local function create()
	local tip, leftside = CreateFrame("GameTooltip"), {}
	for i = 1,6 do
		local L,R = tip:CreateFontString(), tip:CreateFontString()
		L:SetFontObject(GameFontNormal)
		R:SetFontObject(GameFontNormal)
		tip:AddFontStrings(L,R)
		leftside[i] = L
	end
	
	tip.leftside = leftside
	return tip
end

-- The filter itself

local legionFilter = addon:RegisterFilter("Legion", 92, 'ABEvent-1.0')
legionFilter.uiName = L['Legion']
legionFilter.uiDesc = L['Put Legion Stuff in their own sections.']

function legionFilter:OnInitialize()
	self.db = addon.db:RegisterNamespace('Legion', {
		profile = { enableAP = true, enableAR = true, enableChampionEquip = true },
		char = {	},
	})
end

local function unescape(String)
  local Result = tostring(String)
  Result = gsub(Result, "|c........", "") -- Remove color start.
  Result = gsub(Result, "|r", "") -- Remove color end.
  Result = gsub(Result, "|H.-|h(.-)|h", "%1") -- Remove links.
  Result = gsub(Result, "|T.-|t", "") -- Remove textures.
  Result = gsub(Result, "{.-}", "") -- Remove raid target icons.
  return Result
end

function legionFilter:Update()
	MatchIDs = nil
	self:SendMessage('AdiBags_FiltersChanged')
end

function legionFilter:OnEnable()
	addon:UpdateFilters()
end

function legionFilter:OnDisable()
	addon:UpdateFilters()
end

local setNames = {}

function legionFilter:Filter(slotData)
	MatchIDs = MatchIDs or MatchIDs_Init(self)
	if self.db.profile.enableChampionEquip and MatchIDs[slotData.itemId] then
		return L["Champion's Equipment"]
	end

	tooltip = tooltip or create()
	tooltip:SetOwner(UIParent,"ANCHOR_NONE")
	tooltip:ClearLines()

	if slotData.bag == BANK_CONTAINER then
		tooltip:SetInventoryItem("player", BankButtonIDToInvSlotID(slotData.slot, nil))
	else
		tooltip:SetBagItem(slotData.bag, slotData.slot)
	end

	for i = 1,6 do
		local t = unescape(tooltip.leftside[i]:GetText())
		if t ~= nil and self.db.profile.enableAP and t == "Artifact Power" then
			return L["Artifact Power"]
		elseif t ~= nil and self.db.profile.enableAR and (string.sub(t, -string.len(L["Artifact Relic"])) == L["Artifact Relic"]) then
			return L["Artifact Relic"]
		end
	end
	
	tooltip:Hide()
end

function legionFilter:GetOptions()
	return {
		enableAP = {
			name = L['Enable Artifact Power'],
			desc = L['Check this if you want a section for Artifact Power items.'],
			type = 'toggle',
			order = 10,
		},
		enableAR = {
			name = L['Enable Artifact Relic'],
			desc = L['Check this if you want a section for Artifact Relic items.'],
			type = 'toggle',
			order = 20,
		},
		enableChampionEquip = {
			name = L['Enable Champion\'s Equipment'],
			desc = L['Check this if you want a section for Champion\'s Equipment items.'],
			type = 'toggle',
			order = 30,
		},
	}, addon:GetOptionHandler(self, false, function() return self:Update() end)
end
